@@ -29,9 +29,9 @@ class JWTAuthVerifierTestMixin(test_verifier.BaseJWTAuthVerifierTest):
         m_public_key_ret.retrieve.return_value = pub_key_pem.decode()
         return m_public_key_ret
 
-    def _setup_jwt_auth_verifier(self, pub_key_pem):
+    def _setup_jwt_auth_verifier(self, pub_key_pem, **kwargs):
         m_public_key_ret = self._setup_mock_public_key_retriever(pub_key_pem)
-        return SyncJWTAuthVerifier(m_public_key_ret, loop=self.loop)
+        return SyncJWTAuthVerifier(m_public_key_ret, loop=self.loop, **kwargs)
 
 
 class JWTAuthVerifierRS256Test(
